summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/qtobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/api/qtobject.h')
-rw-r--r--lib/kross/api/qtobject.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/lib/kross/api/qtobject.h b/lib/kross/api/qtobject.h
index 29f493a4..119a579e 100644
--- a/lib/kross/api/qtobject.h
+++ b/lib/kross/api/qtobject.h
@@ -17,16 +17,16 @@
* Boston, MA 02110-1301, USA.
***************************************************************************/
-#ifndef KROSS_API_QTOBJECT_H
-#define KROSS_API_QTOBJECT_H
+#ifndef KROSS_API_TQTOBJECT_H
+#define KROSS_API_TQTOBJECT_H
#include "class.h"
-#include <qstring.h>
-#include <qobject.h>
+#include <tqstring.h>
+#include <tqobject.h>
-// Forward-declaration of the builtin Qt QUObject struct.
-struct QUObject;
+// Forward-declaration of the builtin TQt TQUObject struct.
+struct TQUObject;
namespace Kross { namespace Api {
@@ -37,10 +37,10 @@ namespace Kross { namespace Api {
class ScriptContrainer;
/**
* Class to wrap \a QObject or inherited instances.
*
* This class publishs all SIGNAL's, SLOT's and Q_PROPERTY's
* the QObject has.
*/
class QtObject : public Kross::Api::Class<QtObject>
{
@@ -54,13 +54,13 @@ namespace Kross { namespace Api {
/**
* Constructor.
*
* \param object The \a QObject instance this
* class wraps.
* \param name The unique name this \a QtObject
* instance has. If not defined then the
* \a QObject::name() will be used.
*/
- QtObject(QObject* object, const QString& name = QString::null);
+ QtObject(TQObject* object, const TQString& name = TQString());
/**
* Destructor.
@@ -68,32 +68,32 @@ namespace Kross { namespace Api {
virtual ~QtObject();
/// \see Kross::Api::Object::getClassName()
- virtual const QString getClassName() const;
+ virtual const TQString getClassName() const;
/**
* Return the \a QObject instance this class wraps.
*
* \return The wrapped QObject.
*/
- QObject* getObject();
+ TQObject* getObject();
/**
* Build a Qt QUObject struct out of the Qt signal or
* slot signature and the passed \a List arguments.
*
* \throw RuntimeException If the try to translate \p arguments
* failed.
- * \param signature The Qt signal or slot signature.
+ * \param signature The TQt signal or slot signature.
* \param arguments The optional \a List of arguments.
- * \return A QUObject array.
+ * \return A TQUObject array.
*/
- static QUObject* toQUObject(const QString& signature, List::Ptr arguments);
+ static TQUObject* toTQUObject(const TQString& signature, List::Ptr arguments);
private:
- /// The wrapped QObject.
- QObject* m_object;
+ /// The wrapped TQObject.
+ TQObject* m_object;
- // QProperty's
+ // TQProperty's
/// Return a list of property names.
Kross::Api::Object::Ptr propertyNames(Kross::Api::List::Ptr);
@@ -122,9 +122,9 @@ namespace Kross { namespace Api {
/// Emit a signal.
Kross::Api::Object::Ptr emitSignal(Kross::Api::List::Ptr);
/// Connect signal with a QObject slot.
Kross::Api::Object::Ptr connectSignal(Kross::Api::List::Ptr);
/// Disconnect signal from QObject slot.
Kross::Api::Object::Ptr disconnectSignal(Kross::Api::List::Ptr);
};
@@ -37,10 +37,10 @@ namespace Kross { namespace Api {
class ScriptContrainer;
/**
- * Class to wrap \a QObject or inherited instances.
+ * Class to wrap \a TQObject or inherited instances.
*
@@ -37,10 +37,10 @@ namespace Kross { namespace Api {
*
- * This class publishs all SIGNAL's, SLOT's and Q_PROPERTY's
- * the QObject has.
+ * This class publishs all SIGNAL's, SLOT's and TQ_PROPERTY's
+ * the TQObject has.
*/
class QtObject : public Kross::Api::Class<QtObject>
@@ -54,13 +54,13 @@ namespace Kross { namespace Api {
* Constructor.
*
- * \param object The \a QObject instance this
+ * \param object The \a TQObject instance this
* class wraps.
* \param name The unique name this \a QtObject
@@ -54,13 +54,13 @@ namespace Kross { namespace Api {
* \param name The unique name this \a QtObject
* instance has. If not defined then the
- * \a QObject::name() will be used.
+ * \a TQObject::name() will be used.
*/
@@ -68,32 +68,32 @@ namespace Kross { namespace Api {
/**
- * Return the \a QObject instance this class wraps.
+ * Return the \a TQObject instance this class wraps.
*
@@ -68,32 +68,32 @@ namespace Kross { namespace Api {
*
- * \return The wrapped QObject.
+ * \return The wrapped TQObject.
*/
@@ -68,32 +68,32 @@ namespace Kross { namespace Api {
/**
- * Build a Qt QUObject struct out of the Qt signal or
+ * Build a TQt TQUObject struct out of the TQt signal or
* slot signature and the passed \a List arguments.
*
@@ -122,9 +122,9 @@ namespace Kross { namespace Api {
/// Emit a signal.
Kross::Api::Object::Ptr emitSignal(Kross::Api::List::Ptr);
- /// Connect signal with a QObject slot.
+ /// Connect signal with a TQObject slot.
Kross::Api::Object::Ptr connectSignal(Kross::Api::List::Ptr);
@@ -122,9 +122,9 @@ namespace Kross { namespace Api {
Kross::Api::Object::Ptr connectSignal(Kross::Api::List::Ptr);
- /// Disconnect signal from QObject slot.
+ /// Disconnect signal from TQObject slot.
Kross::Api::Object::Ptr disconnectSignal(Kross::Api::List::Ptr);
};